@@ -1,24 +1,24 @@
 /* mpfr_round_raw_generic -- Generic rounding function
 
-Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008 Free Software Foundation, Inc.
+Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
 Contributed by the Arenaire and Cacao projects, INRIA.
 
-This file is part of the MPFR Library.
+This file is part of the GNU MPFR Library.
 
-The MPFR Library is free software; you can redistribute it and/or modify
+The GNU MPFR Library is free software; you can redistribute it and/or modify
 it under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at your
+the Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
-The MPFR Library is distributed in the hope that it will be useful, but
+The GNU MPFR Library is distributed in the hope that it will be useful, but
 WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the MPFR Library; see the file COPYING.LIB.  If not, write to
-the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
-MA 02110-1301, USA. */
+along with the GNU MPFR Library; see the file COPYING.LESSER.  If not, see
+http://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
+51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
 
 #ifndef flag
 # error "ERROR: flag must be defined (0 / 1)"
@@ -39,7 +39,7 @@ MA 02110-1301, USA. */
  * is a power of two.
  *
  * If inexp != NULL, put in *inexp the inexact flag of the rounding (0, 1, -1).
- * In case of even rounding when rnd = GMP_RNDN, put MPFR_EVEN_INEX (2) or
+ * In case of even rounding when rnd = MPFR_RNDN, put MPFR_EVEN_INEX (2) or
  * -MPFR_EVEN_INEX (-2) in *inexp.
  *
  * If flag = 1, just returns whether one should add 1 or not for rounding.
@@ -55,8 +55,8 @@ mpfr_round_raw_generic(
 #if flag == 0
                        mp_limb_t *yp,
 #endif
-                       const mp_limb_t *xp, mp_prec_t xprec,
-                       int neg, mp_prec_t yprec, mp_rnd_t rnd_mode
+                       const mp_limb_t *xp, mpfr_prec_t xprec,
+                       int neg, mpfr_prec_t yprec, mpfr_rnd_t rnd_mode
 #if use_inexp != 0
                        , int *inexp
 #endif
@@ -80,9 +80,9 @@ mpfr_round_raw_generic(
       (xprec <= yprec || MPFR_IS_LIKE_RNDZ (rnd_mode, neg)))
     return 0;
 
-  xsize = (xprec-1)/BITS_PER_MP_LIMB + 1;
-  nw = yprec / BITS_PER_MP_LIMB;
-  rw = yprec & (BITS_PER_MP_LIMB - 1);
+  xsize = (xprec-1)/GMP_NUMB_BITS + 1;
+  nw = yprec / GMP_NUMB_BITS;
+  rw = yprec & (GMP_NUMB_BITS - 1);
 
   if (MPFR_UNLIKELY(xprec <= yprec))
     { /* No rounding is necessary. */
@@ -107,7 +107,7 @@ mpfr_round_raw_generic(
       if (MPFR_LIKELY(rw))
         {
           nw++;
-          lomask = MPFR_LIMB_MASK (BITS_PER_MP_LIMB - rw);
+          lomask = MPFR_LIMB_MASK (GMP_NUMB_BITS - rw);
           himask = ~lomask;
         }
       else
@@ -118,10 +118,10 @@ mpfr_round_raw_generic(
       MPFR_ASSERTD(k >= 0);
       sb = xp[k] & lomask;  /* First non-significant bits */
       /* Rounding to nearest ? */
-      if (MPFR_LIKELY( rnd_mode == GMP_RNDN) )
+      if (MPFR_LIKELY( rnd_mode == MPFR_RNDN) )
         {
           /* Rounding to nearest */
-          mp_limb_t rbmask = MPFR_LIMB_ONE << (BITS_PER_MP_LIMB - 1 - rw);
+          mp_limb_t rbmask = MPFR_LIMB_ONE << (GMP_NUMB_BITS - 1 - rw);
           if (sb & rbmask) /* rounding bit */
             sb &= ~rbmask; /* it is 1, clear it */
           else
@@ -134,7 +134,7 @@ mpfr_round_raw_generic(
           /* rounding to nearest, with rounding bit = 1 */
           if (MPFR_UNLIKELY(sb == 0)) /* Even rounding. */
             {
-              /* sb == 0 && rnd_mode == GMP_RNDN */
+              /* sb == 0 && rnd_mode == MPFR_RNDN */
               sb = xp[xsize - nw] & (himask ^ (himask << 1));
               if (sb == 0)
                 {
@@ -143,7 +143,7 @@ mpfr_round_raw_generic(
                   /* ((neg!=0)^(sb!=0)) ? MPFR_EVEN_INEX  : -MPFR_EVEN_INEX;*/
                   /* Since neg = 0 or 1 and sb=0*/
 #if flag == 1
-                  return 0 /*sb != 0 && rnd_mode != GMP_RNDZ */;
+                  return 0 /*sb != 0 && rnd_mode != MPFR_RNDZ */;
 #else
                   MPN_COPY_INCR(yp, xp + xsize - nw, nw);
                   yp[0] &= himask;
@@ -152,7 +152,7 @@ mpfr_round_raw_generic(
                 }
               else
                 {
-                  /* sb != 0 && rnd_mode == GMP_RNDN */
+                  /* sb != 0 && rnd_mode == MPFR_RNDN */
                   if (use_inexp)
                     *inexp = MPFR_EVEN_INEX-2*MPFR_EVEN_INEX*neg;
                   /*((neg!=0)^(sb!=0))? MPFR_EVEN_INEX  : -MPFR_EVEN_INEX; */
@@ -160,18 +160,18 @@ mpfr_round_raw_generic(
                   goto rnd_RNDN_add_one_ulp;
                 }
             }
-          else /* sb != 0  && rnd_mode == GMP_RNDN*/
+          else /* sb != 0  && rnd_mode == MPFR_RNDN*/
             {
               if (use_inexp)
                 /* *inexp = (neg == 0) ? 1 : -1; but since neg = 0 or 1 */
                 *inexp = 1-2*neg;
             rnd_RNDN_add_one_ulp:
 #if flag == 1
-              return 1; /*sb != 0 && rnd_mode != GMP_RNDZ;*/
+              return 1; /*sb != 0 && rnd_mode != MPFR_RNDZ;*/
 #else
               carry = mpn_add_1 (yp, xp + xsize - nw, nw,
                                  rw ?
-                                 MPFR_LIMB_ONE << (BITS_PER_MP_LIMB - rw)
+                                 MPFR_LIMB_ONE << (GMP_NUMB_BITS - rw)
                                  : MPFR_LIMB_ONE);
               yp[0] &= himask;
               return carry;
@@ -181,16 +181,16 @@ mpfr_round_raw_generic(
       /* Rounding to Zero ? */
       else if (MPFR_IS_LIKE_RNDZ(rnd_mode, neg))
         {
-          /* rnd_mode == GMP_RNDZ */
+          /* rnd_mode == MPFR_RNDZ */
         rnd_RNDZ:
           while (MPFR_UNLIKELY(sb == 0) && k > 0)
             sb = xp[--k];
           if (use_inexp)
-            /* rnd_mode == GMP_RNDZ and neg = 0 or 1 */
-            /* (neg != 0) ^ (rnd_mode != GMP_RNDZ)) ? 1 : -1);*/
+            /* rnd_mode == MPFR_RNDZ and neg = 0 or 1 */
+            /* (neg != 0) ^ (rnd_mode != MPFR_RNDZ)) ? 1 : -1);*/
             *inexp = MPFR_UNLIKELY(sb == 0) ? 0 : (2*neg-1);
 #if flag == 1
-          return 0; /*sb != 0 && rnd_mode != GMP_RNDZ;*/
+          return 0; /*sb != 0 && rnd_mode != MPFR_RNDZ;*/
 #else
           MPN_COPY_INCR(yp, xp + xsize - nw, nw);
           yp[0] &= himask;
@@ -204,9 +204,9 @@ mpfr_round_raw_generic(
             sb = xp[--k];
           if (MPFR_UNLIKELY(sb == 0))
             {
-              /* sb = 0 && rnd_mode != GMP_RNDZ */
+              /* sb = 0 && rnd_mode != MPFR_RNDZ */
               if (use_inexp)
-                /* (neg != 0) ^ (rnd_mode != GMP_RNDZ)) ? 1 : -1);*/
+                /* (neg != 0) ^ (rnd_mode != MPFR_RNDZ)) ? 1 : -1);*/
                 *inexp = 0;
 #if flag == 1
               return 0;
@@ -218,15 +218,15 @@ mpfr_round_raw_generic(
             }
           else
             {
-              /* sb != 0 && rnd_mode != GMP_RNDZ */
+              /* sb != 0 && rnd_mode != MPFR_RNDZ */
               if (use_inexp)
-                /* (neg != 0) ^ (rnd_mode != GMP_RNDZ)) ? 1 : -1);*/
+                /* (neg != 0) ^ (rnd_mode != MPFR_RNDZ)) ? 1 : -1);*/
                 *inexp = 1-2*neg;
 #if flag == 1
               return 1;
 #else
               carry = mpn_add_1(yp, xp + xsize - nw, nw,
-                                rw ? MPFR_LIMB_ONE << (BITS_PER_MP_LIMB - rw)
+                                rw ? MPFR_LIMB_ONE << (GMP_NUMB_BITS - rw)
                                 : 1);
               yp[0] &= himask;
               return carry;
@@ -238,12 +238,12 @@ mpfr_round_raw_generic(
     {
       /* Roundind mode = Zero / No inexact flag */
 #if flag == 1
-      return 0 /*sb != 0 && rnd_mode != GMP_RNDZ*/;
+      return 0 /*sb != 0 && rnd_mode != MPFR_RNDZ*/;
 #else
       if (MPFR_LIKELY(rw))
         {
           nw++;
-          himask = ~MPFR_LIMB_MASK (BITS_PER_MP_LIMB - rw);
+          himask = ~MPFR_LIMB_MASK (GMP_NUMB_BITS - rw);
         }
       else
         himask = ~(mp_limb_t) 0;
