@@ -1,24 +1,24 @@
 /* Test file for mpfr_check.
 
-Copyright 2003, 2004, 2006, 2007, 2008 Free Software Foundation, Inc.
+Copyright 2003, 2004, 2006, 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
 Contributed by the Arenaire and Cacao projects, INRIA.
 
-This file is part of the MPFR Library.
+This file is part of the GNU MPFR Library.
 
-The MPFR Library is free software; you can redistribute it and/or modify
+The GNU MPFR Library is free software; you can redistribute it and/or modify
 it under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at your
+the Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
-The MPFR Library is distributed in the hope that it will be useful, but
+The GNU MPFR Library is distributed in the hope that it will be useful, but
 WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the MPFR Library; see the file COPYING.LIB.  If not, write to
-the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
-MA 02110-1301, USA. */
+along with the GNU MPFR Library; see the file COPYING.LESSER.  If not, see
+http://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
+51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -50,18 +50,18 @@ main (void)
       MPFR_SET_ZERO(a);
       if (!mpfr_check(a)) ERROR("for zero");
       /* Check var */
-      mpfr_set_ui(a, 2, GMP_RNDN);
+      mpfr_set_ui(a, 2, MPFR_RNDN);
       if (!mpfr_check(a)) ERROR("for set_ui");
       mpfr_clear_overflow();
       max = 1000; /* Allows max 2^1000 bits for the exponent */
       while ((!mpfr_overflow_p()) && (max>0))
         {
-          mpfr_mul(a, a, a, GMP_RNDN);
+          mpfr_mul(a, a, a, MPFR_RNDN);
           if (!mpfr_check(a)) ERROR("for mul");
           max--;
         }
       if (max==0) ERROR("can't reach overflow");
-      mpfr_set_ui(a, 2137, GMP_RNDN);
+      mpfr_set_ui(a, 2137, MPFR_RNDN);
       /* Corrupt a and check for it */
       MPFR_SIGN(a) = 2;
       if (mpfr_check(a))  ERROR("sgn");
@@ -69,8 +69,16 @@ main (void)
       /* Check prec */
       MPFR_PREC(a) = 1;
       if (mpfr_check(a))  ERROR("precmin");
-      MPFR_PREC(a) = MPFR_PREC_MAX+1;
-      if (mpfr_check(a))  ERROR("precmax");
+#if MPFR_VERSION_MAJOR < 3
+      /* Disable the test with MPFR >= 3 since mpfr_prec_t is now signed.
+         The "if" below is sufficient, but the MPFR_PREC_MAX+1 generates
+         a warning with GCC 4.4.4 even though the test is always false. */
+      if ((mpfr_prec_t) 0 - 1 > 0)
+        {
+          MPFR_PREC(a) = MPFR_PREC_MAX+1;
+          if (mpfr_check(a))  ERROR("precmax");
+        }
+#endif
       MPFR_PREC(a) = pr;
       if (!mpfr_check(a)) ERROR("prec");
       /* Check exponent */
@@ -96,16 +104,16 @@ main (void)
       MPFR_SET_ALLOC_SIZE(a, s);
       /* Check normal form */
       tmp = MPFR_MANT(a)[0];
-      if ((pr % BITS_PER_MP_LIMB) != 0)
+      if ((pr % GMP_NUMB_BITS) != 0)
         {
           MPFR_MANT(a)[0] = ~0;
           if (mpfr_check(a))  ERROR("last bits non 0");
         }
       MPFR_MANT(a)[0] = tmp;
-      MPFR_MANT(a)[MPFR_LIMB_SIZE(a)-1] &= MPFR_LIMB_MASK (BITS_PER_MP_LIMB-1);
+      MPFR_MANT(a)[MPFR_LIMB_SIZE(a)-1] &= MPFR_LIMB_MASK (GMP_NUMB_BITS-1);
       if (mpfr_check(a))  ERROR("last bits non 0");
       /* Final */
-      mpfr_set_ui(a, 2137, GMP_RNDN);
+      mpfr_set_ui(a, 2137, MPFR_RNDN);
       if (!mpfr_check(a)) ERROR("after last set");
       mpfr_clear (a);
       if (mpfr_check(a))  ERROR("after clear");
