@@ -1,13 +1,13 @@
 /* mpfr_tlngamma -- test file for lngamma function
 
-Copyright 2005, 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
+Copyright 2005, 2006, 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
 Contributed by the Arenaire and Cacao projects, INRIA.
 
 This file is part of the GNU MPFR Library.
 
 The GNU MPFR Library is free software; you can redistribute it and/or modify
 it under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at your
+the Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
 The GNU MPFR Library is distributed in the hope that it will be useful, but
@@ -16,9 +16,9 @@ or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the GNU MPFR Library; see the file COPYING.LIB.  If not, write to
-the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
-MA 02110-1301, USA. */
+along with the GNU MPFR Library; see the file COPYING.LESSER.  If not, see
+http://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
+51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -39,7 +39,7 @@ special (void)
   mpfr_init (y);
 
   mpfr_set_nan (x);
-  mpfr_lngamma (y, x, GMP_RNDN);
+  mpfr_lngamma (y, x, MPFR_RNDN);
   if (!mpfr_nan_p (y))
     {
       printf ("Error for lngamma(NaN)\n");
@@ -47,7 +47,7 @@ special (void)
     }
 
   mpfr_set_inf (x, -1);
-  mpfr_lngamma (y, x, GMP_RNDN);
+  mpfr_lngamma (y, x, MPFR_RNDN);
   if (!mpfr_nan_p (y))
     {
       printf ("Error for lngamma(-Inf)\n");
@@ -55,48 +55,48 @@ special (void)
     }
 
   mpfr_set_inf (x, 1);
-  mpfr_lngamma (y, x, GMP_RNDN);
+  mpfr_lngamma (y, x, MPFR_RNDN);
   if (!mpfr_inf_p (y) || mpfr_sgn (y) < 0)
     {
       printf ("Error for lngamma(+Inf)\n");
       exit (1);
     }
 
-  mpfr_set_ui (x, 0, GMP_RNDN);
-  mpfr_lngamma (y, x, GMP_RNDN);
+  mpfr_set_ui (x, 0, MPFR_RNDN);
+  mpfr_lngamma (y, x, MPFR_RNDN);
   if (!mpfr_inf_p (y) || mpfr_sgn (y) < 0)
     {
       printf ("Error for lngamma(+0)\n");
       exit (1);
     }
 
-  mpfr_set_ui (x, 0, GMP_RNDN);
-  mpfr_neg (x, x, GMP_RNDN);
-  mpfr_lngamma (y, x, GMP_RNDN);
+  mpfr_set_ui (x, 0, MPFR_RNDN);
+  mpfr_neg (x, x, MPFR_RNDN);
+  mpfr_lngamma (y, x, MPFR_RNDN);
   if (!mpfr_nan_p (y))
     {
       printf ("Error for lngamma(-0)\n");
       exit (1);
     }
 
-  mpfr_set_ui (x, 1, GMP_RNDN);
-  mpfr_lngamma (y, x, GMP_RNDN);
+  mpfr_set_ui (x, 1, MPFR_RNDN);
+  mpfr_lngamma (y, x, MPFR_RNDN);
   if (MPFR_IS_NAN (y) || mpfr_cmp_ui (y, 0) || MPFR_IS_NEG (y))
     {
       printf ("Error for lngamma(1)\n");
       exit (1);
     }
 
-  mpfr_set_si (x, -1, GMP_RNDN);
-  mpfr_lngamma (y, x, GMP_RNDN);
+  mpfr_set_si (x, -1, MPFR_RNDN);
+  mpfr_lngamma (y, x, MPFR_RNDN);
   if (!mpfr_nan_p (y))
     {
       printf ("Error for lngamma(-1)\n");
       exit (1);
     }
 
-  mpfr_set_ui (x, 2, GMP_RNDN);
-  mpfr_lngamma (y, x, GMP_RNDN);
+  mpfr_set_ui (x, 2, MPFR_RNDN);
+  mpfr_lngamma (y, x, MPFR_RNDN);
   if (MPFR_IS_NAN (y) || mpfr_cmp_ui (y, 0) || MPFR_IS_NEG (y))
     {
       printf ("Error for lngamma(2)\n");
@@ -109,9 +109,9 @@ special (void)
 #define CHECK_X1 "1.0762904832837976166"
 #define CHECK_Y1 "-0.039418362817587634939"
 
-  mpfr_set_str (x, CHECK_X1, 10, GMP_RNDN);
-  mpfr_lngamma (y, x, GMP_RNDN);
-  mpfr_set_str (x, CHECK_Y1, 10, GMP_RNDN);
+  mpfr_set_str (x, CHECK_X1, 10, MPFR_RNDN);
+  mpfr_lngamma (y, x, MPFR_RNDN);
+  mpfr_set_str (x, CHECK_Y1, 10, MPFR_RNDN);
   if (MPFR_IS_NAN (y) || mpfr_cmp (y, x))
     {
       printf ("mpfr_lngamma("CHECK_X1") is wrong:\n"
@@ -124,9 +124,9 @@ special (void)
 
 #define CHECK_X2 "9.23709516716202383435e-01"
 #define CHECK_Y2 "0.049010669407893718563"
-  mpfr_set_str (x, CHECK_X2, 10, GMP_RNDN);
-  mpfr_lngamma (y, x, GMP_RNDN);
-  mpfr_set_str (x, CHECK_Y2, 10, GMP_RNDN);
+  mpfr_set_str (x, CHECK_X2, 10, MPFR_RNDN);
+  mpfr_lngamma (y, x, MPFR_RNDN);
+  mpfr_set_str (x, CHECK_Y2, 10, MPFR_RNDN);
   if (MPFR_IS_NAN (y) || mpfr_cmp (y, x))
     {
       printf ("mpfr_lngamma("CHECK_X2") is wrong:\n"
@@ -139,8 +139,8 @@ special (void)
 
   mpfr_set_prec (x, 8);
   mpfr_set_prec (y, 175);
-  mpfr_set_ui (x, 33, GMP_RNDN);
-  mpfr_lngamma (y, x, GMP_RNDU);
+  mpfr_set_ui (x, 33, MPFR_RNDN);
+  mpfr_lngamma (y, x, MPFR_RNDU);
   mpfr_set_prec (x, 175);
   mpfr_set_str_binary (x, "0.1010001100011101101011001101110010100001000001000001110011000001101100001111001001000101011011100100010101011110100111110101010100010011010010000101010111001100011000101111E7");
   if (MPFR_IS_NAN (y) || mpfr_cmp (x, y))
@@ -151,8 +151,8 @@ special (void)
 
   mpfr_set_prec (x, 21);
   mpfr_set_prec (y, 8);
-  mpfr_set_ui (y, 120, GMP_RNDN);
-  mpfr_lngamma (x, y, GMP_RNDZ);
+  mpfr_set_ui (y, 120, MPFR_RNDN);
+  mpfr_lngamma (x, y, MPFR_RNDZ);
   mpfr_set_prec (y, 21);
   mpfr_set_str_binary (y, "0.111000101000001100101E9");
   if (MPFR_IS_NAN (x) || mpfr_cmp (x, y))
@@ -166,7 +166,7 @@ special (void)
   mpfr_set_prec (x, 3);
   mpfr_set_prec (y, 206);
   mpfr_set_str_binary (x, "0.110e10");
-  inex = mpfr_lngamma (y, x, GMP_RNDN);
+  inex = mpfr_lngamma (y, x, MPFR_RNDN);
   mpfr_set_prec (x, 206);
   mpfr_set_str_binary (x, "0.10000111011000000011100010101001100110001110000111100011000100100110110010001011011110101001111011110110000001010100111011010000000011100110110101100111000111010011110010000100010111101010001101000110101001E13");
   if (MPFR_IS_NAN (y) || mpfr_cmp (x, y))
@@ -183,7 +183,7 @@ special (void)
   mpfr_set_prec (x, 4);
   mpfr_set_prec (y, 4);
   mpfr_set_str_binary (x, "0.1100E-66");
-  mpfr_lngamma (y, x, GMP_RNDN);
+  mpfr_lngamma (y, x, MPFR_RNDN);
   mpfr_set_str_binary (x, "0.1100E6");
   if (MPFR_IS_NAN (y) || mpfr_cmp (x, y))
     {
@@ -193,10 +193,10 @@ special (void)
 
   mpfr_set_prec (x, 256);
   mpfr_set_prec (y, 32);
-  mpfr_set_si_2exp (x, -1, 200, GMP_RNDN);
-  mpfr_add_ui (x, x, 1, GMP_RNDN);
-  mpfr_div_2ui (x, x, 1, GMP_RNDN);
-  mpfr_lngamma (y, x, GMP_RNDN);
+  mpfr_set_si_2exp (x, -1, 200, MPFR_RNDN);
+  mpfr_add_ui (x, x, 1, MPFR_RNDN);
+  mpfr_div_2ui (x, x, 1, MPFR_RNDN);
+  mpfr_lngamma (y, x, MPFR_RNDN);
   mpfr_set_prec (x, 32);
   mpfr_set_str_binary (x, "-0.10001000111011111011000010100010E207");
   if (MPFR_IS_NAN (y) || mpfr_cmp (x, y))
@@ -211,10 +211,10 @@ special (void)
 
   mpfr_set_prec (x, 256);
   mpfr_set_prec (y, 32);
-  mpfr_set_si_2exp (x, -1, 200, GMP_RNDN);
-  mpfr_sub_ui (x, x, 1, GMP_RNDN);
-  mpfr_div_2ui (x, x, 1, GMP_RNDN);
-  mpfr_lngamma (y, x, GMP_RNDN);
+  mpfr_set_si_2exp (x, -1, 200, MPFR_RNDN);
+  mpfr_sub_ui (x, x, 1, MPFR_RNDN);
+  mpfr_div_2ui (x, x, 1, MPFR_RNDN);
+  mpfr_lngamma (y, x, MPFR_RNDN);
   if (!mpfr_nan_p (y))
     {
       printf ("Error for lngamma(-2^199-0.5)\n");
